======================
Time Series Catalogues
======================

.. image:: https://github.com/SciQLop/tscat/actions/workflows/test_main.yml/badge.svg
        :target: https://github.com/pboettch/tscat/actions/workflows/test_main.yml

.. image:: https://codecov.io/gh/SciQLop/tscat/branch/main/graph/badge.svg
        :target: https://codecov.io/gh/SciQLop/tscat
        :alt: Coverage Status


A library which stores, loads and filters time-series-events and associates them catalogues and
dynamic catalogues (filter-based).


* Free software: GNU General Public License v3
* Documentation: https://tscat.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
